API Documentation
=================

The *python-maec* APIs are the recommended tools for reading, writing, and manipulating MAEC XML documents.

.. note::

    The python-maec APIs are currently under development. As such, API coverage of MAEC data constructs is incomplete; please bear with us as we work toward complete coverage. This documentation also serves to outline current API coverage.

**MAEC** -- Modules located in the base `maec`_ package

.. _maec: https://github.com/MAECProject/python-maec/tree/master/maec

.. toctree::
    :titlesonly:

    __init__

**MAEC Bundle** -- Modules located in the `maec.bundle`_ package

.. _maec.bundle: https://github.com/MAECProject/python-maec/tree/master/maec/bundle

.. toctree::
    :titlesonly:
    :glob:

    bundle/*

**MAEC Package** -- Modules located in the `maec.package`_ package

.. _maec.package: https://github.com/MAECProject/python-maec/tree/master/maec/package

.. toctree::
    :titlesonly:
    :glob:

    package/*

**MAEC Utils** -- Modules located in the `maec.utils`_ package

.. _maec.utils: https://github.com/MAECProject/python-maec/tree/master/maec/utils

.. toctree::
    :titlesonly:
    :glob:

    utils/*

**MAEC Analytics** -- Modules located in the `maec.analytics`_ package

.. _maec.analytics: https://github.com/MAECProject/python-maec/tree/master/maec/analytics

.. toctree::
    :titlesonly:
    :glob:

    analytics/*
